#include "stm32f2xx.h"
#include "LedAndKey.h"

//LED IO define					
#define IO_LED_ARRAY GPIOE
#define RCC_IO_LED RCC_AHB1Periph_GPIOE
#define IO_LED1 GPIO_Pin_7
#define IO_LED2 GPIO_Pin_8
#define IO_LED3 GPIO_Pin_9
#define IO_LED4 GPIO_Pin_10

//KEY IO define					
#define IO_KEY_ARRAY GPIOB
#define RCC_IO_KEY RCC_AHB1Periph_GPIOB
#define IO_KEY1 GPIO_Pin_13
#define IO_KEY2 GPIO_Pin_14
#define IO_KEY3 GPIO_Pin_15

//JOYSTICK IO define					
#define IO_JOYSTICK_ARRAY GPIOD
#define RCC_IO_JOYSTICK RCC_AHB1Periph_GPIOD
#define IO_JOYSTICK_A GPIO_Pin_8
#define IO_JOYSTICK_B GPIO_Pin_9
#define IO_JOYSTICK_C GPIO_Pin_10
#define IO_JOYSTICK_D GPIO_Pin_11
#define IO_JOYSTICK_P GPIO_Pin_12

//define Key and Joystick Value
#define KEY1_VALUE 1
#define KEY2_VALUE 2
#define KEY3_VALUE 3
#define JOYSTICK_A_VALUE 4
#define JOYSTICK_B_VALUE 5
#define JOYSTICK_C_VALUE 6
#define JOYSTICK_D_VALUE 7
#define JOYSTICK_P_VALUE 8

static uint32_t KeyAndJostickValue;

void Delay(__IO uint32_t nCount)
{
  while(nCount--)
  {
  }
}

void KyeAndJoystickScan(void)
{
	if(!GPIO_ReadInputDataBit( IO_KEY_ARRAY, IO_KEY1))KeyAndJostickValue = KEY1_VALUE;
	if(!GPIO_ReadInputDataBit( IO_KEY_ARRAY, IO_KEY2))KeyAndJostickValue = KEY2_VALUE;
	if(!GPIO_ReadInputDataBit( IO_KEY_ARRAY, IO_KEY3))KeyAndJostickValue = KEY3_VALUE;
	
	if(!GPIO_ReadInputDataBit( IO_JOYSTICK_ARRAY, IO_JOYSTICK_A))KeyAndJostickValue = JOYSTICK_A_VALUE;
	if(!GPIO_ReadInputDataBit( IO_JOYSTICK_ARRAY, IO_JOYSTICK_B))KeyAndJostickValue = JOYSTICK_B_VALUE;
	if(!GPIO_ReadInputDataBit( IO_JOYSTICK_ARRAY, IO_JOYSTICK_C))KeyAndJostickValue = JOYSTICK_C_VALUE;
	if(!GPIO_ReadInputDataBit( IO_JOYSTICK_ARRAY, IO_JOYSTICK_D))KeyAndJostickValue = JOYSTICK_D_VALUE;
	if(!GPIO_ReadInputDataBit( IO_JOYSTICK_ARRAY, IO_JOYSTICK_P))KeyAndJostickValue = JOYSTICK_P_VALUE;
}

void LedShow(void)
{
	if(KeyAndJostickValue == KEY1_VALUE)GPIO_WriteBit( IO_LED_ARRAY, IO_LED1 | IO_LED2,Bit_SET);
	if(KeyAndJostickValue == KEY2_VALUE)GPIO_WriteBit( IO_LED_ARRAY, IO_LED2 | IO_LED3,Bit_SET);
	if(KeyAndJostickValue == KEY3_VALUE)GPIO_WriteBit( IO_LED_ARRAY, IO_LED3 | IO_LED4,Bit_SET);
	
	if(KeyAndJostickValue == JOYSTICK_B_VALUE)GPIO_WriteBit( IO_LED_ARRAY, IO_LED1,Bit_SET);
	if(KeyAndJostickValue == JOYSTICK_C_VALUE)GPIO_WriteBit( IO_LED_ARRAY, IO_LED4,Bit_SET);
	if(KeyAndJostickValue == JOYSTICK_A_VALUE)GPIO_WriteBit( IO_LED_ARRAY, IO_LED2,Bit_SET);
	if(KeyAndJostickValue == JOYSTICK_D_VALUE)GPIO_WriteBit( IO_LED_ARRAY, IO_LED3,Bit_SET);
	if(KeyAndJostickValue == JOYSTICK_P_VALUE)GPIO_WriteBit( IO_LED_ARRAY, IO_LED1 | IO_LED2 | IO_LED3 | IO_LED4,Bit_SET);

	Delay(0x1fffff);
	GPIO_WriteBit( IO_LED_ARRAY, IO_LED1 | IO_LED2 | IO_LED3 | IO_LED4,Bit_RESET);
	Delay(0x1fffff);
}

void LedGpioConfiguration(void)
{
	GPIO_InitTypeDef  GPIO_InitStructure;

	  /* GPIOG Periph clock enable */
	RCC_AHB1PeriphClockCmd  ( RCC_IO_LED, ENABLE);

  /* Configure PG6 and PG8 in output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = IO_LED1 | IO_LED2 | IO_LED3 | IO_LED4;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_100MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
  GPIO_Init( IO_LED_ARRAY, &GPIO_InitStructure);
}

void KeyGpioConfiguration(void)
{
	GPIO_InitTypeDef  GPIO_InitStructure;

	  /* GPIOG Periph clock enable */
	RCC_AHB1PeriphClockCmd  ( RCC_IO_KEY, ENABLE);

  /* Configure PG6 and PG8 in output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = IO_KEY1 | IO_KEY2 | IO_KEY3;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_100MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP;
  GPIO_Init( IO_KEY_ARRAY, &GPIO_InitStructure);
}

void JoystickGpioConfiguration(void)
{
	GPIO_InitTypeDef  GPIO_InitStructure;

	  /* GPIOG Periph clock enable */
	RCC_AHB1PeriphClockCmd  ( RCC_IO_JOYSTICK, ENABLE);

  /* Configure PG6 and PG8 in output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = IO_JOYSTICK_A | IO_JOYSTICK_B | IO_JOYSTICK_C | IO_JOYSTICK_D | IO_JOYSTICK_P;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_100MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP;
  GPIO_Init( IO_JOYSTICK_ARRAY, &GPIO_InitStructure);
}
